---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

Please describe the bug and supplement the additional information:
 - OS, Python and their versions
 - content of the config file `stm32pio.ini`
 - your project folder tree

Also, try the same action that causes the error with a verbose output feature turned on and paste its output. It can be done like this:
 - for CLI version use `-v` option: `stm32pio -v new -d ...`
 - for GUI version go to **Menu** - **Settings** and check the corresponding element. Click **Save**
